summaryrefslogtreecommitdiffstats
path: root/ash/wm/panels/panel_layout_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/wm/panels/panel_layout_manager.h')
-rw-r--r--ash/wm/panels/panel_layout_manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/ash/wm/panels/panel_layout_manager.h b/ash/wm/panels/panel_layout_manager.h
index 042d285..71d22d2 100644
--- a/ash/wm/panels/panel_layout_manager.h
+++ b/ash/wm/panels/panel_layout_manager.h
@@ -37,7 +37,7 @@ class Widget;
}
namespace ash {
-class Launcher;
+class Shelf;
namespace internal {
class PanelCalloutWidget;
@@ -77,8 +77,8 @@ class ASH_EXPORT PanelLayoutManager
// Returns the callout widget (arrow) for |panel|.
views::Widget* GetCalloutWidgetForPanel(aura::Window* panel);
- ash::Launcher* launcher() { return launcher_; }
- void SetLauncher(ash::Launcher* launcher);
+ Shelf* shelf() { return shelf_; }
+ void SetShelf(Shelf* shelf);
// Overridden from aura::LayoutManager:
virtual void OnWindowResized() OVERRIDE;
@@ -172,8 +172,8 @@ class ASH_EXPORT PanelLayoutManager
PanelList panel_windows_;
// The panel being dragged.
aura::Window* dragged_panel_;
- // The launcher we are observing for launcher icon changes.
- Launcher* launcher_;
+ // The shelf we are observing for shelf icon changes.
+ Shelf* shelf_;
// The shelf layout manager being observed for visibility changes.
ShelfLayoutManager* shelf_layout_manager_;